DocumentBlock

Struct DocumentBlock 

pub struct DocumentBlock {
    pub title: String,
    pub content: Vec<u8>,
    pub format_hint: FormatHint,
}
DOCUMENT block — represents prose or documentation content.

Used for READMEs, design docs, comments, or any non-code textual content that provides context to the LLM. The format_hint tells the renderer how to interpret the body (markdown, plain text, HTML).

Field layout within body:

┌──────────┬───────────┬─────────────┬──────────────────────────┐
│ Field ID │ Wire Type │ Name        │ Description              │
├──────────┼───────────┼─────────────┼──────────────────────────┤
│ 1        │ Bytes     │ title       │ Document title           │
│ 2        │ Bytes     │ content     │ Document body            │
│ 3        │ Varint    │ format_hint │ FormatHint enum byte     │
└──────────┴───────────┴─────────────┴──────────────────────────┘

Fields

title: Stringcontent: Vec<u8>format_hint: FormatHint

Implementations

Source

impl DocumentBlock

pub fn encode_body(&self) -> Vec<u8>

Serialize this block’s fields into a TLV-encoded body.

pub fn decode_body(buf: &[u8]) -> Result<Self, TypeError>

Deserialize a DOCUMENT block from a TLV-encoded body.