ExtensionBlock

Struct ExtensionBlock 

pub struct ExtensionBlock {
    pub namespace: String,
    pub type_name: String,
    pub content: Vec<u8>,
}
EXTENSION block — user-defined block type.

Provides an escape hatch for custom content that doesn’t fit the 10 built-in block types. Extensions are namespaced to avoid collisions between different organizations or tools.

Field layout within body:

┌──────────┬───────────┬───────────┬───────────────────────────┐
│ Field ID │ Wire Type │ Name      │ Description               │
├──────────┼───────────┼───────────┼───────────────────────────┤
│ 1        │ Bytes     │ namespace │ Namespace (e.g. "myorg")  │
│ 2        │ Bytes     │ type_name │ Type within namespace     │
│ 3        │ Bytes     │ content   │ Opaque content bytes      │
└──────────┴───────────┴───────────┴───────────────────────────┘

The content field is opaque — the BCP decoder does not attempt to parse it. Only consumers that understand the namespace/type_name pair will interpret the content.

Fields

namespace: Stringtype_name: Stringcontent: Vec<u8>

Implementations

Source

impl ExtensionBlock

pub fn encode_body(&self) -> Vec<u8>

Serialize this block’s fields into a TLV-encoded body.

pub fn decode_body(buf: &[u8]) -> Result<Self, TypeError>

Deserialize an EXTENSION block from a TLV-encoded body.